import { csv } from 'd3';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

const sectionColors = [
  		'gold', '#2788bc', 'Pink', 'silver', 'Grey', 'slateblue', '#69b3a2', 'wheat', 'lightgreen', 'aqua'
		  ]; 
const csvUrl = 'https://gist.githubusercontent.com/codingcooper/4218f77a9f3be57aee3057eac51afed8/raw/85aa5c5d5e0a2d5b0ad73c750259e811697a6196/Top10RichPersons.csv';
//fetching data from dataset
const fetchData = async () => {
  const data = await csv(csvUrl);
  return data;
};

const svg = select("svg");
const width = + svg.attr('width');
const height = + svg.attr('height');

const xAxisTickFormat = number =>
  	format('.4~g')(number);

const render = (data, total) => {
  const pieData = pie().value(d=>d.Total_net_worth_inBillionDollars)(data);
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(sectionColors);
  
  const arcGenerator = d3.arc()
  .innerRadius(0)
  .outerRadius(250);

  //arc
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,220)`)
  	.selectAll("path").data(pieData);
  
  sections.enter()
    .append("path")
    .attr("d", segments)
  	.attr("fill", d => colors(d.data.Total_net_worth_inBillionDollars));
  //section label
  sections
    .enter()
    .append('text')
    .text(d => xAxisTickFormat((d.data.Total_net_worth_inBillionDollars))+"B")
    .attr("transform", function(d) { return "translate(" + arcGenerator.centroid(d) + ")";  })
    .style("text-anchor", "middle")
  	.style('fill', 'black')
    .style("font-size", 15);
  //legends
  const legends = svg.append("g")
  	.attr("transform", "translate(500,70)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.Total_net_worth_inBillionDollars));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Name);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data.Total_net_worth_inBillionDollars))+" Billion $");
}

const run = async () => {
  let data = await fetchData()
  let total = 0
  data.forEach(d=>{
    d.Total_net_worth_inBillionDollars = +d.Total_net_worth_inBillionDollars;
    total += d.Total_net_worth_inBillionDollars
  });
	render(data,total);
};
run();